@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.79';
+$Test::BDD::Cucumber::Executor::VERSION = '0.80';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.79
+version 0.80
 
 =head1 DESCRIPTION
 
@@ -20,6 +20,8 @@ use MooX::HandlesVia;
 use Types::Standard qw( Bool Str ArrayRef HashRef );
 use List::Util qw/first any/;
 use Module::Runtime qw/use_module/;
+use utf8;
+use Encode ();
 
 use Test2::API qw/intercept/;
 
@@ -648,7 +650,7 @@ sub dispatch {
             # from out of the other results first.
             output => $self->_test_output(
                 (first { $_->isa('Test2::Event::Subtest') }
-                 @$events)->{subevents})
+                 @$events)->{subevents}),
         });
     warn qq|Unsupported: Step modified C->stash instead of C->stash->{scenario} or C->stash->{feature}|
         if $stash_keys ne (join ';', sort keys %{$context->stash});
@@ -708,7 +710,7 @@ sub _test_output {
     $self->_test_output_from_subevents($events, $fmt, \$idx);
     close $stdout;
 
-    return $out_text;
+    return Encode::decode('utf8', $out_text);
 }
 
 sub _test_output_from_subevents {
